#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 casa-types
version:              0.0.3
visibility:           public
id:                   casa-types-0.0.3-4Zy7wWH7JGdEJ6jroFuET9
key:                  casa-types-0.0.3-4Zy7wWH7JGdEJ6jroFuET9
license:              BSD-3-Clause
copyright:
    2018-2019 FP Complete,
    2024-2025 Haskell Foundation

maintainer:
    Chris Done <chrisdone@fpcomplete.com>,
    Mike Pilgrem <public@pilgrem.com>

author:               Chris Done
homepage:             https://github.com/commercialhaskell/casa#readme
synopsis:             Types for Casa
description:
    Types for Casa (Content-Addressable Storage Archive). See
    <https://casa.stackage.org/>

category:             Development
abi:                  82d25553aa50691bdd210db2e807f000
exposed:              True
exposed-modules:      Casa.Types
import-dirs:          /usr/lib/ghc-9.6.6/site-local/casa-types-0.0.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/casa-types-0.0.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/casa-types-0.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-casa-types
hs-libraries:         HScasa-types-0.0.3-4Zy7wWH7JGdEJ6jroFuET9
depends:
    aeson-2.2.1.0-BfV39Vpjeh9G4TP9CsFVxm
    attoparsec-0.14.4-AfQXKZj0AFm4MwPZbnzhvC base-4.18.2.1
    base16-bytestring-1.0.2.0-BqWVRU1IQoAP0y3rqebgF bytestring-0.11.5.3
    hashable-1.4.7.0-D2jhP8LVtgFIAnKx76ZNYr
    path-pieces-0.2.1-ILPSumWqTsA51OyVDS7ISl
    persistent-2.14.5.2-A5NvEfJNpLZ8RfP1fNLxvx text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-casa-types/html/casa-types.haddock
haddock-html:         /usr/share/doc/haskell-casa-types/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

